@@ -1,6 +1,6 @@
 package App::mkfeyorm;
 BEGIN {
-  $App::mkfeyorm::VERSION = '0.007';
+  $App::mkfeyorm::VERSION = '0.008';
 }
 # ABSTRACT: Make skeleton code with Fey::ORM
 
@@ -183,22 +183,22 @@ sub process {
     my $self = shift;
 
     $self->process_schema;
-    $self->_process_tables($_, $self->tables->{$_}) for keys %{ $self->tables };
+    $self->process_table($_, $self->tables->{$_}) for keys %{ $self->tables };
 }
 
 sub process_tables {
     my ( $self, @tables ) = @_;
 
     if (@tables) {
-        $self->_process_tables($_, $self->tables->{$_}) for @tables;
+        $self->process_table($_, $self->tables->{$_}) for @tables;
     }
     else {
-        $self->_process_tables($_, $self->tables->{$_}) for keys %{ $self->tables };
+        $self->process_table($_, $self->tables->{$_}) for keys %{ $self->tables };
     }
 }
 
 sub process_schema {
-    my $self = shift;
+    my ( $self, $content ) = @_;
 
     my $schema = $self->schema_module;
     my @tables = $self->table_modules;
@@ -213,12 +213,12 @@ sub process_schema {
     $self->_template->process(
         \$self->schema_template,
         $vars,
-        $self->_gen_module_path($schema),
+        ref $content eq 'SCALAR' ? $content : $self->module_path($schema),
     ) or die $self->_template->error, "\n";
 }
 
-sub _process_tables {
-    my ( $self, $orig_table, $db_table ) = @_;
+sub process_table {
+    my ( $self, $orig_table, $db_table, $content ) = @_;
 
     $db_table = _db_table_name($orig_table) unless $db_table;
 
@@ -236,11 +236,11 @@ sub _process_tables {
     $self->_template->process(
         \$self->table_template,
         $vars,
-        $self->_gen_module_path($table),
+        ref $content eq 'SCALAR' ? $content : $self->module_path($table),
     ) or die $self->_template->error, "\n";
 }
 
-sub _gen_module_path {
+sub module_path {
     my ( $self, $module ) = @_;
 
     return catfile( split(/::/, $module) ) . '.pm';
@@ -262,7 +262,7 @@ App::mkfeyorm - Make skeleton code with Fey::ORM
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -373,6 +373,12 @@ Generate the schema module.
 
     $app->process_schema;
 
+=head2 process_table
+
+Generate the talbe module.
+
+    $app->process_table;
+
 =head2 process_tables
 
 Generate the table module.
@@ -388,6 +394,10 @@ Get full name of schema module
 
 Get full names of table modules
 
+=head2 module_path
+
+Get module path from module names
+
 =head1 SEE ALSO
 
 L<Fey::ORM>
@@ -417,6 +427,7 @@ use Fey::ORM::Schema;
 [% FOREACH TABLE = TABLES -%]
 use [% TABLE %];
 [% END -%]
+
 [% IF CACHE -%]
 use Storable;
 use File::Basename;
